@@ -35,6 +35,13 @@ FILTERED_ENTRIES = 'locate_cached'
 DEFAULT_PID_PATH = os.path.join(tempfile.gettempdir(), 'kdbx.pid')
 
 
+def process_entry(entry):
+    entry = entry.strip()
+    if entry.endswith('/'):
+        return None
+    return os.path.split(entry)[1].lower()
+
+
 def sort_entry_filter_key(term):
     def f(entry):
         if term == entry:
@@ -93,7 +100,7 @@ class Handler:
     def _refresh_cache(self):
         self.process.sendline('ls -R -f')
         self.db_name, entries = self.result(max(1, self.process.timeout))  # increase timeout for listing
-        self.entries = [e.strip().lower() for e in entries]
+        self.entries = list(filter(bool, map(process_entry, entries)))
 
     def run_in_background(self):
         if os.fork():
@@ -113,10 +120,9 @@ class Handler:
         return 'Database is closed'
 
     def get_filtered_entries(self, term):
-        response = filter(lambda e: term in e, self.entries)
-        response = sorted(response, key=sort_entry_filter_key(term), reverse=True)
-
-        return self.process.crlf.join(response)
+        self.process.sendline('locate ' + term)
+        self.db_name, entries = self.result()
+        return self.process.crlf.join(entries)
 
     async def _handler(self, reader, writer):
         data = (await reader.readuntil()).decode().strip()
